#!/bin/bash
# maintainer       : Patrick Smith <penguin0601@earthlink.net> 
# Source location  : http://sourceforge.net/projects/ming
# Home URL         : http://www.libming.org/
# binary info      : This binary built for Zenwalk Linux 5.x
# 

#
# what package is going to be built
#
softname='ming'
softversion="0.4.0.beta5"
sourcearchive="$softname-$softversion.tar.bz2"

#
# The ZenWalk package version: indicated for/on what ZenWalk version
# the package has been created
#
# example: packageversion='1Z20' means: 
# 1  -> build 1 = first build, special: 0 = experimental/unsupported build
# Z  -> ZenWalk
# 20 -> ZenWalk version 2.0; 26 -> zenwalk 2.6 
#
packageversion='52.1'

#
# where could you get the source
#
srcurl="http://downloads.sourceforge.net/ming/ming-0.4.0.beta5.tar.bz2"

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 make-jobs at once
#
#numjobs='-j6'
#
# I only have a 'light' computer: 2 make-jobs at once
#
numjobs='-j2'

#
#---------------------------------------------------------------------
# Note: for a rebuild you should normally not have to change anything
# below this comment
#---------------------------------------------------------------------
#

#
# a lonesome 'hook': the other end is at the bottom of the buildfile
# the combination gives me a full log of the build-process in the
# file: "$softname-$softversion-info.txt"
#
(

#
# we're going to do some cwd-hopping: this requires that we keep track
# of the starting-point
#
buildir=$(pwd)

#
# We'll use the SlackWare/ZenWalk database of installed packages: 
# The directory: /var/log/packages keeps a set of all installed 
# ZenWalk packages: one file per installed package
#

echo "-- build-time dependencies check -----"

depsok=passed

cd /var/log/packages
 
#
# build-time dependencies check
#
for file in \
   \
   \
; do
 
   #
   # Check the dependency
   #
   if [ -f $file-?.* ] ; then 
      echo "package: $file is installed: `ls -d $file*`: good ...";
   else
      echo "package: $file not found: please install a $file package first";
      depsok=fail
   fi
   #
done

cd $buildir
 
echo "Dependencies check result: $depsok"
#
# check if all dependencies are there
#
if [[ $depsok == passed ]]; then
   unset $depsok;
else
   exit 1;
fi

#
# check if the source files archive is present: we can do little without
# it
#
echo "-- source archive check -----"

if [ -r "$sourcearchive" ]; then 
  echo "Usable source archive: $sourcearchive found: good ...";
else 
  echo "No source archive: $sourcearchive found"
  echo "It is not possible to build the package without a source archive"
  echo "file; Please download the source archive from:"
  echo
  echo "$srcurl"
  echo
  exit 1;
fi

#
# start the real work
#
echo "-- start of the package building -----"

#
# the package 'destination'
#
prefix=/usr

#
# The architecture that the package is built for:
#
# arch='i486' -> the compiler uses only 80486 instructions
# tune='i686'  -> the optimising is done for a PII and above CPU
#
arch='i486'
tune='i686'

#
# parameters needed for the build process
#
package="$softname-$softversion-$arch-$packageversion"

#
# do package-specific settings 
#
# This avoids compiling a version number into KDE's .la files:
#QTDIR=/usr/lib/qt
#export QTDIR

#
# KDE additions:
#
#KDEDIR=$prefix
#PATH=$PATH:$KDEDIR/bin
#MANPATH=$MANPATH:$KDEDIR/man
#export KDEDIR PATH MANPATH

#
# prepare the build result directory
#
dest="$buildir/$package"
#
rm -rf $dest
#
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
#
# prepare the directory for the build-file and assorted other 
# user-build related things
#
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

#
# put a slack-desc in place
#
cat <<EOF > $dest/install/slack-desc
           |----------------------------MING--------------------------------------------|
$softname:  Ming
$softname:       Ming
$softname:            Ming is a library for generating Macromedia Flash files (.swf)
$softname: written in C, and includes useful utilities for working with .swf files.
$softname: 
$softname: It has wrappers that allow it to be used in C++, PHP, Python, Ruby, and Perl
$softname: 
$softname: 
$softname: 
$softname:
$softname: 
EOF

echo "-- Unpacking the source archive -----"

#
# loop over expanded package source files
#
cd $buildir
srcdir="$softname-$softversion"
rm -rf $srcdir
tar xf $sourcearchive
cd $srcdir  

#
# set target permissions
#
chown -R root.root . 
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

#
# configure package for compilation
#
echo "-- configure -----"

export CFLAGS="-O2 -march=$arch -mtune=$tune"  
export CXXFLAGS="-O2 -march=$arch -mtune=$tune"  
./configure \
      --prefix=$prefix \
	  --enable-python \
	  --enable-perl \
	  --enable-php \
 #     --enable-tcl \
      
#
# make package
#
echo "-- make -----"

make $numjobs 

#
# install package to the target directory
#
echo "-- make install -----"

make install DESTDIR=$dest

#
# add 'default' files from the package source
#
echo "-- adding default files -----"

mkdir -p $dest/usr/doc/$srcdir
cp -a \
  AUTHORS COPYING ChangeLog INSTALL HISTORY LICENSE LICENSE_GPL2 NEWS README TODO \
  $dest/usr/doc/$srcdir 

# 
# as per package rules: add the build-file itself
#
echo "-- adding package-rules files -----"

cp "$buildir/build-$softname.sh" \
   "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"
#
# generate an executable script that can be used to get the source
#
cat <<EOF > "$destsrc/getsrc.sh"
# 
# get the source(s) script
#
wget -c $srcurl
EOF

#
# it works easier if this file is actually executable :-)
#
chmod a+x "$destsrc/getsrc.sh"

#
# post-build processing: 
# - strip executables 
# - compress man-pages
#
echo "-- pre-package processing files -----"

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  for mandir in $(find . -name man -type d) ; do
    if [ -d $mandir ]; then
      ( cd $mandir
        find . -type f -name "*.?" -exec gzip -9 {} \;
      )
    fi
  done
)

# mkdir -p $dest/usr/man/
# mv -f $dest/usr/share/man/man1 $dest/usr/man
# mv -f $dest/usr/share/man/man3 $dest/usr/man
# rm -rf $dest/usr/share/man

#
# real packaging work: 
#
chown -R root.root $dest/$prefix

echo "--- packaging -----"

cd $dest
makepkg -l y -c n $dest.tgz
(
 cd $buildir
 echo "--- generating the md5sum -----"
 md5sum $package.tgz >$package.md5
 echo "--- generating the package dependencies -----"
 ADD=tcl,php requiredbuilder -z $package.tgz >$package.dep
 echo "---generating the build log file---"
)

#
# the other end of the lonesome hook: 
#
) 2>&1 | tee "$softname-$softversion-build.txt"

